@@ -256,6 +256,12 @@ def calcAngSepDeg(RADeg1, decDeg1, RADeg2, decDeg2):
             a[mask]=1.0
         else:
             a=1.0
+    mask=numpy.less(a, -1.0)
+    if mask.sum() > 0:
+        if type(a) == numpy.ndarray:
+            a[mask]=-1.0
+        else:
+            a=-1.0
     r=numpy.degrees(numpy.arccos(a))
             
     # Above gives nan when RADeg1, decDeg1 == RADeg1, decDeg2
@@ -347,7 +353,7 @@ def convertCoords(inputSystem, outputSystem, coordX, coordY, epoch):
             outputSystem=="GALACTIC":
 
             outCoords=wcscon.wcscon(wcscon.wcscsys(inputSystem),
-                wcscon.wcscsys(outputSystem), 0, 0, coordX, coordY, epoch)
+                wcscon.wcscsys(outputSystem), 0, 0, float(coordX), float(coordY), epoch)
 
             return outCoords
 
